// #autoload
// #name = Pilot Mode II
// #version = 1.75
// #date = 18 July 2003
// #author = ilys
// #warrior = ilys
// #credit = Based on PilotMode II by Barbarian, which is based on PilotMode by Crunchy
// #category = ilys' Scripts
// #description = Increase mouse sensitivity whilst pilot, makes it much easier to control the vehicle.  This is a modification to add pitch and yaw Sensitivity sliders.
// #readme = scripts/autoexec/PilotMode.txt
// #config = PilotModeDialog
//
// --- Main Code ---
//

// Lookup table for %yFlags instead of complicated logic.
// Mouse Inverted?, Invert in vehicle?, Deadzone?
$PilotMode::Flags[0, 0, 0] = "S";
$PilotMode::Flags[0, 0, 1] = "SD";
$PilotMode::Flags[0, 1, 0] = "SI";
$PilotMode::Flags[0, 1, 1] = "SDI";
$PilotMode::Flags[1, 0, 0] = "SI";
$PilotMode::Flags[1, 0, 1] = "SDI";
$PilotMode::Flags[1, 1, 0] = "S";
$PilotMode::Flags[1, 1, 1] = "SD";


// note, if you add vehicle types up here you must also add a button and pane in the gui for it
$PilotMode::numtypes = 10;

// Type names used in ClientCmdSetHudMode
$PilotMode::VehicleType[1] = "Hoverbike";
$PilotMode::VehicleType[2] = "Assault";
$PilotMode::VehicleType[3] = "MPB";
$PilotMode::VehicleType[4] = "Shrike";
$PilotMode::VehicleType[5] = "Bomber";
$PilotMode::VehicleType[6] = "HAPC";
// Types for Team Aerial Combat
// The Heavy APC in TAC is called HAPC, same as the Tribes 2 Havoc, so we'll fix this with a kludge later in the script
// -- if TAC is active, we'll rename the vehicle before applying the function lookups.
$PilotMode::VehicleType[7] = "FLPC";
$PilotMode::VehicleType[8] = "TACBomber";
$PilotMode::VehicleType[9] = "TACHAPC";
$PilotMode::VehicleType[10] = "HawkEye";

// Nice names used for display
$PilotMode::VehicleName[1] = "Wildcat";
$PilotMode::VehicleName[2] = "Beowulf";
$PilotMode::VehicleName[3] = "Jericho";
$PilotMode::VehicleName[4] = "Shrike";
$PilotMode::VehicleName[5] = "Thundersword";
$PilotMode::VehicleName[6] = "Havoc";
$PilotMode::VehicleName[7] = "TacFLPC";
$PilotMode::VehicleName[8] = "TacBomber";
$PilotMode::VehicleName[9] = "TacHAPC";
$PilotMode::VehicleName[10] = "TacHawkEye";

// TAC equivalence table.  we have custom tabs for the flying vehicles and use the
// equivalents for the ground vehicles.  Also lets us change HAPC to TACHAPC in the lookup tables
// air vehicles
$PilotMode::TACBaseHawkEye="HawkEye";
$PilotMode::TACBaseHAPC="TACHAPC";
$PilotMode::TACBaseTACBomber="TACBomber";
$PilotMode::TACBaseFLPC="FLPC";
// ground vehicles
$PilotMode::TACBaseMPB="MPB";
$PilotMode::TACBaseTACAssault="Assault";
$PilotMode::TACBaseHoverbike="Hoverbike";

// START package PilotMode
package PilotMode {

function PilotModeSetScale(%factorPitch, %factorYaw, %sensPitch, %sensYaw, %deadzone)
{
    %bind = moveMap.getBinding(pitch);
    %devicePitch = getField(%bind, 0);
    %actionPitch = getField(%bind, 1);
    %bind = moveMap.getBinding(yaw);
    %deviceYaw = getField(%bind, 0);
    %actionYaw = getField(%bind, 1);

    %yFlags = $PilotMode::Flags[moveMap.isInverted(%devicePitch, %actionPitch), $pref::Vehicle::InvertYAxis, %deadzone];
    %scalePitch = %sensPitch*%factorPitch;
    %scaleYaw   = %sensYaw*%factorYaw;

    if (%deadzone)
    {
        %yDeadZone = moveMap.getDeadZone(%devicePitch, %actionPitch);
        %xDeadZone = moveMap.getDeadZone(%deviceYaw,   %actionYaw);
    	passengerKeys.bind(%devicePitch, %actionPitch, %yFlags, %yDeadZone, %scalePitch, pitch);
    	passengerKeys.bind(%deviceYaw,   %actionYaw,   "SD",    %xDeadZone, %scaleYaw,   yaw);
    }
    else
    {
    	passengerKeys.bind(%devicePitch, %actionPitch, %yFlags, %scalePitch, pitch);
    	passengerKeys.bind(%deviceYaw,   %actionYaw,   "S",     %scaleYaw,   yaw);
    }
}

function ClientCmdSetHudMode(%mode, %type, %node)
{
    parent::ClientCmdSetHudMode(%mode, %type, %node);

    %mode = detag(%mode);

    if (%mode $= "Pilot" && !$PilotMode::isPassenger)
    {
	%usetype=%type;

	// TAC check, if so fix the HAPC since TAC uses the same name
	if (isObject(TACCreditsGui))
	{
		%usetype=$PilotMode::TACBase[%usetype];

		// grr, TAC sticks a random number in front of the HawkEye vehicle
		if( strstr(%type, "HawkEye") > 0 )
			%usetype="HawkEye";

		// echo("Pilotmode.cs: debug: TAC mode enabled: " @ %usetype);
	}

	if ( $PilotModePref::Factor[%usetype, pitch] !$= "" )
	{
	        %deadZone   = $PilotModePref::Deadzone[%usetype];
	        %scalePitch = $PilotModePref::Factor[%usetype, pitch];
        	%scaleYaw   = $PilotModePref::Factor[%usetype, yaw];
        	%sensPitch  = $PilotModePref::Sens[%usetype, pitch]*2;
        	%sensYaw    = $PilotModePref::Sens[%usetype, yaw]*2;
 	        schedule(300, 0, PilotModeSetScale(%scalePitch, %scaleYaw, %sensPitch, %sensYaw, %deadZone));
	}
	else
		echo("Pilotmode.cs: unsupported vehicle type: " @ %usetype @ "/" @ %type @ "-- not changing anything");

	// echo("Pilotmode.cs: debug: " @ %usetype @ "/" @ %type);
    }
    
}

function PilotModeConvertOld()
{
	//stop cluttering clientprefs.cs
	if(! $PilotModePref::convertedsave )
	{
		$PilotModePref::convertedsave=true;
		for (%i = 1; %i <= $PilotMode::numtypes; %i++)
		{
			$PilotModePref::Factor[%type, yaw]=$pref::PilotMode::Factor[%type, yaw];
			$PilotModePref::Factor[%type, pitch]=$pref::PilotMode::Factor[%type, pitch];
			$PilotModePref::Deadzone[%type]=$pref::PilotMode::Deadzone[%type];
		}

		deleteVariables("$pref::PilotMode::*");
		export("$PilotModePref::*", "prefs/pilotmodeprefs.cs", false);
	}

}

function PilotModeLoadValues()
{
        $PilotMode::Link = $PilotModePref::Factor["Shrike", yaw] == $PilotModePref::Factor["Shrike", pitch];
	for (%i = 1; %i <= $PilotMode::numtypes; %i++)
	{
		%type = $PilotMode::VehicleType[%i];
		%x = $PilotModePref::Factor[%type, yaw];
		%y = $PilotModePref::Factor[%type, pitch];
                PilotModeDialog.FactorSlider[%i, yaw].setValue(%x);
                PilotModeDialog.FactorSlider[%i, pitch].setValue(%y);
                PilotModeDialog.FactorText[%i, yaw].setValue("X-Axis Factor: ("@getSubStr(%x, 0, 4)@"x)");
                PilotModeDialog.FactorText[%i, pitch].setValue("Y-Axis Factor: ("@getSubStr(%y, 0, 4)@"x)");
		%a = $PilotModePref::Sens[%type, yaw];
		%b = $PilotModePref::Sens[%type, pitch];
                PilotModeDialog.SensSlider[%i, yaw].setValue(%a);
                PilotModeDialog.SensSlider[%i, pitch].setValue(%b);
                PilotModeDialog.SensText[%i, yaw].setValue("X-Axis Sens: ("@getSubStr(%a, 0, 4)@"x)");
                PilotModeDialog.SensText[%i, pitch].setValue("Y-Axis Sens: ("@getSubStr(%b, 0, 4)@"x)");

		//fixed, wasn't setting the dead zone toggle value
                PilotModeDialog.DeadZoneTgl[%i].setValue($PilotModePref::Deadzone[%type]);
	}

    PilotModeDialogLinkTgl.setValue($PilotMode::Link);
    PilotModeDialogInvertTgl.setValue($pref::Vehicle::InvertYAxis);
}

function PilotModeDialog::OnWake(%this)
{
	PilotModeLoadValues();

    %this.setPane(%this.pane);
}

function PilotModeDialog::OnSleep(%this)
{
        PilotModeDialogSave();
}

function PilotModeDialogSave()
{
	for (%i = 1; %i <= $PilotMode::numtypes; %i++)
	{
        	%type = $PilotMode::VehicleType[%i];
                $PilotModePref::Deadzone[%type] = PilotModeDialog.DeadZoneTgl[%i].getValue();
	}
	export("$PilotModePref::*", "prefs/pilotmodeprefs.cs", false);
}

function PilotModeSetFactor(%i, %command)
{
    %type = $PilotMode::VehicleType[%i];
    %value = PilotModeDialog.FactorSlider[%i, %command].getValue();
	$PilotModePref::Factor[%type, %command] = %value;
    %axis = (%command $= yaw) ? "X-Axis" : "Y-Axis";
    PilotModeDialog.FactorText[%i, %command].setValue(%axis@" Factor: ("@getSubStr(%value, 0, 4)@"x)");

    %altCommand = (%command $= yaw) ? pitch : yaw;
    if ($PilotMode::Link && PilotModeDialog.FactorSlider[%i, %altCommand].getValue() != %value)
    {
        PilotModeDialog.FactorSlider[%i, %altCommand].setValue(%value);
    }
}

function PilotModeSetSens(%i, %command)
{
    %type = $PilotMode::VehicleType[%i];
    %value = PilotModeDialog.SensSlider[%i, %command].getValue();
	$PilotModePref::Sens[%type, %command] = %value;
    %axis = (%command $= yaw) ? "X-Axis" : "Y-Axis";
    PilotModeDialog.SensText[%i, %command].setValue(%axis@" Sens: ("@getSubStr(%value, 0, 4)@"x)");

    %altCommand = (%command $= yaw) ? pitch : yaw;
    if ($PilotMode::Link && PilotModeDialog.SensSlider[%i, %altCommand].getValue() != %value)
    {
        PilotModeDialog.SensSlider[%i, %altCommand].setValue(%value);
    }
}

function PilotModeDialogLinkTgl::onAction(%this)
{
	$PilotMode::Link = %this.getValue();
}

function PilotModeDialogInvertTgl::onAction(%this)
{
	$pref::Vehicle::InvertYAxis = %this.getValue();
}

function PilotModeDialog::setPane(%this, %pane)
{
    %paneObject = "PilotMode_"@%this.pane@"Pane";
    %tabObject  = "PilotMode_"@%this.pane@"Tab";
    %paneObject.setVisible(false);
    %tabObject.setValue(false);

    %paneObject = "PilotMode_"@%pane@"Pane";
    %tabObject  = "PilotMode_"@%pane@"Tab";
    %paneObject.setVisible(true);
    %tabObject.setValue(true);

    %this.pane = %pane;
}
function PilotModeSetup()
{
//--- OBJECT WRITE BEGIN ---
new GuiControl(PilotModeDialog) {
	profile = "GuiDefaultProfile";
	horizSizing = "center";
	vertSizing = "center";
	position = "0 0";
	extent = "400 320";
	minExtent = "8 8";
	visible = "1";
	hideCursor = "0";
	bypassHideCursor = "0";
	helpTag = "0";

	pane = "WILDCAT";

	new ShellBitmapButton() {
		profile = "ShellButtonProfile";
		horizSizing = "right";
		vertSizing = "bottom";
		position = "16 288";
		extent = "82 38";
		minExtent = "32 38";
		visible = "1";
		hideCursor = "0";
		bypassHideCursor = "0";
		command = "PilotModeDialogSave();";
		helpTag = "0";
		text = "SAVE";
		simpleStyle = "0";
	};
	new ShellBitmapButton() {
		profile = "ShellButtonProfile";
		horizSizing = "right";
		vertSizing = "bottom";
		position = "17 262";
		extent = "82 38";
		minExtent = "32 38";
		visible = "1";
		hideCursor = "0";
		bypassHideCursor = "0";
		command = "PilotModeSetDefaults();";
		helpTag = "0";
		text = "DEFAULTS";
		simpleStyle = "0";
	};
	new ShellTabButton(PilotMode_WildcatTab) {
		profile = "ShellTabProfile";
		horizSizing = "right";
		vertSizing = "bottom";
		position = "19 6";
		extent = "120 38";
		minExtent = "48 38";
		visible = "1";
		hideCursor = "0";
		bypassHideCursor = "0";
		command = "PilotModeDialog.setPane(Wildcat);";
		helpTag = "0";
		text = "Wildcat";
		longTextBuffer = "0";
		maxLength = "255";

		simpleStyle = "0";
	};
	new ShellTabButton(PilotMode_BeowulfTab) {
		profile = "ShellTabProfile";
		horizSizing = "right";
		vertSizing = "bottom";
		position = "19 31";
		extent = "120 38";
		minExtent = "48 38";
		visible = "1";
		hideCursor = "0";
		bypassHideCursor = "0";
		command = "PilotModeDialog.setPane(Beowulf);";
		helpTag = "0";
		text = "Beowulf";
		longTextBuffer = "0";
		maxLength = "255";

		simpleStyle = "0";
	};
	new ShellTabButton(PilotMode_JerichoTab) {
		profile = "ShellTabProfile";
		horizSizing = "right";
		vertSizing = "bottom";
		position = "19 56";
		extent = "120 38";
		minExtent = "48 38";
		visible = "1";
		hideCursor = "0";
		bypassHideCursor = "0";
		command = "PilotModeDialog.setPane(Jericho);";
		helpTag = "0";
		text = "Jericho";
		longTextBuffer = "0";
		maxLength = "255";

		simpleStyle = "0";
	};
	new ShellTabButton(PilotMode_ShrikeTab) {
		profile = "ShellTabProfile";
		horizSizing = "right";
		vertSizing = "bottom";
		position = "19 81";
		extent = "120 38";
		minExtent = "48 38";
		visible = "1";
		hideCursor = "0";
		bypassHideCursor = "0";
		command = "PilotModeDialog.setPane(Shrike);";
		helpTag = "0";
		text = "Shrike";
		longTextBuffer = "0";
		maxLength = "255";

		simpleStyle = "0";
	};
	new ShellTabButton(PilotMode_ThunderswordTab) {
		profile = "ShellTabProfile";
		horizSizing = "right";
		vertSizing = "bottom";
		position = "19 106";
		extent = "120 38";
		minExtent = "48 38";
		visible = "1";
		hideCursor = "0";
		bypassHideCursor = "0";
		command = "PilotModeDialog.setPane(Thundersword);";
		helpTag = "0";
		text = "Thundersword";
		longTextBuffer = "0";
		maxLength = "255";

		simpleStyle = "0";
	};
	new ShellTabButton(PilotMode_HavocTab) {
		profile = "ShellTabProfile";
		horizSizing = "right";
		vertSizing = "bottom";
		position = "19 131";
		extent = "120 38";
		minExtent = "48 38";
		visible = "1";
		hideCursor = "0";
		bypassHideCursor = "0";
		command = "PilotModeDialog.setPane(Havoc);";
		helpTag = "0";
		text = "Havoc";
		longTextBuffer = "0";
		maxLength = "255";

		simpleStyle = "0";
	};
	new ShellTabButton(PilotMode_TacFLPCTab) {
		profile = "ShellTabProfile";
		horizSizing = "right";
		vertSizing = "bottom";
		position = "19 156";
		extent = "120 38";
		minExtent = "48 38";
		visible = "1";
		hideCursor = "0";
		bypassHideCursor = "0";
		command = "PilotModeDialog.setPane(TacFLPC);";
		helpTag = "0";
		text = "TacFLPC";
		longTextBuffer = "0";
		maxLength = "255";

		simpleStyle = "0";
	};
	new ShellTabButton(PilotMode_TacBomberTab) {
		profile = "ShellTabProfile";
		horizSizing = "right";
		vertSizing = "bottom";
		position = "19 181";
		extent = "120 38";
		minExtent = "48 38";
		visible = "1";
		hideCursor = "0";
		bypassHideCursor = "0";
		command = "PilotModeDialog.setPane(TacBomber);";
		helpTag = "0";
		text = "TacBomber";
		longTextBuffer = "0";
		maxLength = "255";

		simpleStyle = "0";
	};
	new ShellTabButton(PilotMode_TacHAPCTab) {
		profile = "ShellTabProfile";
		horizSizing = "right";
		vertSizing = "bottom";
		position = "19 206";
		extent = "120 38";
		minExtent = "48 38";
		visible = "1";
		hideCursor = "0";
		bypassHideCursor = "0";
		command = "PilotModeDialog.setPane(TacHAPC);";
		helpTag = "0";
		text = "TacHAPC";
		longTextBuffer = "0";
		maxLength = "255";

		simpleStyle = "0";
	};
	new ShellTabButton(PilotMode_TacHawkEyeTab) {
		profile = "ShellTabProfile";
		horizSizing = "right";
		vertSizing = "bottom";
		position = "19 231";
		extent = "120 38";
		minExtent = "48 38";
		visible = "1";
		hideCursor = "0";
		bypassHideCursor = "0";
		command = "PilotModeDialog.setPane(TacHawkEye);";
		helpTag = "0";
		text = "TacHawkEye";
		longTextBuffer = "0";
		maxLength = "255";

		simpleStyle = "0";
	};
	new ShellTabFrame() {
		profile = "ShellTabFrameProfile";
		horizSizing = "right";
		vertSizing = "bottom";
		position = "133 4";
		extent = "254 286";
		minExtent = "254 26";
		visible = "1";
		hideCursor = "0";
		bypassHideCursor = "0";
		helpTag = "0";
		isVertical = "1";
		useCloseButton = "0";
		edgeInset = "0";
	};
	new ShellFieldCtrl(PilotMode_WildcatPane) {
		profile = "ShellFieldProfile";
		horizSizing = "right";
		vertSizing = "bottom";
		position = "144 15";
		extent = "242 266";
		minExtent = "16 18";
		visible = "0";
		hideCursor = "0";
		bypassHideCursor = "0";
		helpTag = "0";
	};
	new ShellFieldCtrl(PilotMode_BeowulfPane) {
		profile = "ShellFieldProfile";
		horizSizing = "right";
		vertSizing = "bottom";
		position = "144 15";
		extent = "242 266";
		minExtent = "16 18";
		visible = "0";
		hideCursor = "0";
		bypassHideCursor = "0";
		helpTag = "0";
	};
	new ShellFieldCtrl(PilotMode_JerichoPane) {
		profile = "ShellFieldProfile";
		horizSizing = "right";
		vertSizing = "bottom";
		position = "144 15";
		extent = "242 266";
		minExtent = "16 18";
		visible = "0";
		hideCursor = "0";
		bypassHideCursor = "0";
		helpTag = "0";
	};
	new ShellFieldCtrl(PilotMode_ShrikePane) {
		profile = "ShellFieldProfile";
		horizSizing = "right";
		vertSizing = "bottom";
		position = "144 15";
		extent = "242 266";
		minExtent = "16 18";
		visible = "0";
		hideCursor = "0";
		bypassHideCursor = "0";
		helpTag = "0";
	};
	new ShellFieldCtrl(PilotMode_ThunderswordPane) {
		profile = "ShellFieldProfile";
		horizSizing = "right";
		vertSizing = "bottom";
		position = "144 15";
		extent = "242 266";
		minExtent = "16 18";
		visible = "0";
		hideCursor = "0";
		bypassHideCursor = "0";
		helpTag = "0";
	};
	new ShellFieldCtrl(PilotMode_HavocPane) {
		profile = "ShellFieldProfile";
		horizSizing = "right";
		vertSizing = "bottom";
		position = "144 15";
		extent = "242 266";
		minExtent = "16 18";
		visible = "0";
		hideCursor = "0";
		bypassHideCursor = "0";
		helpTag = "0";
	};
	new ShellFieldCtrl(PilotMode_TacFLPCPane) {
		profile = "ShellFieldProfile";
		horizSizing = "right";
		vertSizing = "bottom";
		position = "144 15";
		extent = "242 266";
		minExtent = "16 18";
		visible = "0";
		hideCursor = "0";
		bypassHideCursor = "0";
		helpTag = "0";
	};
	new ShellFieldCtrl(PilotMode_TacBomberPane) {
		profile = "ShellFieldProfile";
		horizSizing = "right";
		vertSizing = "bottom";
		position = "144 15";
		extent = "242 266";
		minExtent = "16 18";
		visible = "0";
		hideCursor = "0";
		bypassHideCursor = "0";
		helpTag = "0";
	};
	new ShellFieldCtrl(PilotMode_TacHAPCPane) {
		profile = "ShellFieldProfile";
		horizSizing = "right";
		vertSizing = "bottom";
		position = "144 15";
		extent = "242 266";
		minExtent = "16 18";
		visible = "0";
		hideCursor = "0";
		bypassHideCursor = "0";
		helpTag = "0";
	};
	new ShellFieldCtrl(PilotMode_TacHawkEyePane) {
		profile = "ShellFieldProfile";
		horizSizing = "right";
		vertSizing = "bottom";
		position = "144 15";
		extent = "242 266";
		minExtent = "16 18";
		visible = "0";
		hideCursor = "0";
		bypassHideCursor = "0";
		helpTag = "0";
	};
	new ShellToggleButton(PilotModeDialogLinkTgl) {
		profile = "ShellRadioProfile";
		horizSizing = "right";
		vertSizing = "bottom";
		position = "128 292";
		extent = "107 30";
		minExtent = "26 27";
		visible = "1";
		hideCursor = "0";
		bypassHideCursor = "0";
		helpTag = "0";
		text = "LINK X / Y";
		longTextBuffer = "0";
		maxLength = "255";
	};
	new ShellToggleButton(PilotModeDialogInvertTgl) {
		profile = "ShellRadioProfile";
		horizSizing = "right";
		vertSizing = "bottom";
		position = "254 292";
		extent = "107 30";
		minExtent = "26 27";
		visible = "1";
		hideCursor = "0";
		bypassHideCursor = "0";
		helpTag = "0";
		text = "Invert Y-Axis";
		longTextBuffer = "0";
		maxLength = "255";
	};
};
//--- OBJECT WRITE END ---

	exec("prefs/pilotmodeprefs.cs");
	PilotModeConvertOld();
	// If we're missing values for any settings, load them
	PilotModeLoadMissing();
	export("$PilotModePref::*", "prefs/pilotmodeprefs.cs", false);

        $PilotMode::Link = $PilotModePref::Factor["Shrike", yaw] == $PilotModePref::Factor["Shrike", pitch];

	for (%i = 1; %i <= $PilotMode::numtypes; %i++)
	{
  	   %pane = "PilotMode_"@$PilotMode::VehicleName[%i]@"Pane";

     	   PilotModeDialog.SensText[%i, yaw] = new GuiTextCtrl()
     	   {
     	      profile = "ShellTextProfile";
    	      horizSizing = "right";
   	      vertSizing = "bottom";
    	      position = "50 13";
   	      extent = "100 22";
    	      minExtent = "8 8";
   	      visible = "1";
    	      helpTag = "0";
     	      text = "X-Axis Sens:";
    	      maxLength = "255";
     	   };
     	  PilotModeDialog.SensText[%i, pitch] = new GuiTextCtrl()
   	    {
    	    profile = "ShellTextProfile";
     	    horizSizing = "right";
            vertSizing = "bottom";
     	    position = "50 63";
            extent = "100 22";
            minExtent = "8 8";
            visible = "1";
            helpTag = "0";
            text = "Y-Axis Sens:";
            maxLength = "255";
        };
        %pane.add(PilotModeDialog.SensText[%i, yaw]);
        %pane.add(PilotModeDialog.SensText[%i, pitch]);

        PilotModeDialog.SensSlider[%i, yaw] = new ShellSliderCtrl()
        {
            profile = "ShellSliderProfile";
            horizSizing = "right";
            vertSizing = "bottom";
            position = "2 30";
            extent = "240 24";
            minExtent = "12 24";
            visible = "1";
            variable = "value";
            altCommand = "PilotModeSetSens("@%i@", yaw);";
            helpTag = "0";
            range = "0.00 1.00";
            ticks = "1200";
            usePlusMinus = "1";
        };
        PilotModeDialog.SensSlider[%i, pitch] = new ShellSliderCtrl()
        {
            profile = "ShellSliderProfile";
            horizSizing = "right";
            vertSizing = "bottom";
            position = "2 80";
            extent = "240 24";
            minExtent = "12 24";
            visible = "1";
            variable = "value";
            altCommand = "PilotModeSetSens("@%i@", pitch);";
            helpTag = "0";
            range = "0.00 1.00";
            ticks = "1200";
            usePlusMinus = "1";
        };
        %pane.add(PilotModeDialog.SensSlider[%i, yaw]);
        %pane.add(PilotModeDialog.SensSlider[%i, pitch]);

     	  PilotModeDialog.FactorText[%i, yaw] = new GuiTextCtrl()
     	   {
     	      profile = "ShellTextProfile";
    	      horizSizing = "right";
   	      vertSizing = "bottom";
    	      position = "50 113";
   	      extent = "100 22";
    	      minExtent = "8 8";
   	      visible = "1";
    	      helpTag = "0";
     	      text = "X-Axis Factor:";
    	      maxLength = "255";
     	   };
     	  PilotModeDialog.FactorText[%i, pitch] = new GuiTextCtrl()
   	    {
    	    profile = "ShellTextProfile";
     	    horizSizing = "right";
            vertSizing = "bottom";
     	    position = "50 163";
            extent = "100 22";
            minExtent = "8 8";
            visible = "1";
            helpTag = "0";
            text = "Y-Axis Factor:";
            maxLength = "255";
        };
        %pane.add(PilotModeDialog.FactorText[%i, yaw]);
        %pane.add(PilotModeDialog.FactorText[%i, pitch]);

        PilotModeDialog.FactorSlider[%i, yaw] = new ShellSliderCtrl()
        {
            profile = "ShellSliderProfile";
            horizSizing = "right";
            vertSizing = "bottom";
            position = "2 130";
            extent = "240 24";
            minExtent = "12 24";
            visible = "1";
            variable = "value";
            altCommand = "PilotModeSetFactor("@%i@", yaw);";
            helpTag = "0";
            range = "0.00 6.00";
            ticks = "1200";
            usePlusMinus = "1";
        };
        PilotModeDialog.FactorSlider[%i, pitch] = new ShellSliderCtrl()
        {
            profile = "ShellSliderProfile";
            horizSizing = "right";
            vertSizing = "bottom";
            position = "2 180";
            extent = "240 24";
            minExtent = "12 24";
            visible = "1";
            variable = "value";
            altCommand = "PilotModeSetFactor("@%i@", pitch);";
            helpTag = "0";
            range = "0.00 6.00";
            ticks = "1200";
            usePlusMinus = "1";
        };
        %pane.add(PilotModeDialog.FactorSlider[%i, yaw]);
        %pane.add(PilotModeDialog.FactorSlider[%i, pitch]);

        PilotModeDialog.DeadZoneTgl[%i] = new ShellToggleButton()
	{
		profile = "ShellRadioProfile";
		horizSizing = "right";
		vertSizing = "bottom";
		position = "45 222";
		extent = "127 30";
		minExtent = "26 27";
		visible = "1";
		helpTag = "0";
		text = "DEAD ZONE";
		maxLength = "255";
	};
        %pane.add(PilotModeDialog.DeadZoneTgl[%i]);

    }
}

function PilotModeSetDefaults()
{
    MessageBoxYesNo("Defaults", "Are you sure you want to set default values?", "PilotModeSetDefaultsOk();", "");
}


function PilotModeSetDefaultsOk()
{
    PilotModeDefaults();
    export("$PilotModePref::*", "prefs/pilotmodeprefs.cs", false);
    PilotModeLoadValues();

    //save the options now.
    PilotModeDialogSave();
}

function PilotModeLoadMissing()
{
	// Defaults
	$PilotMode::DefaultsHoverbike_yaw=2;
	$PilotMode::DefaultsHoverbike_pitch=2;
	$PilotMode::DefaultsHoverbike_deadzone=false;
	$PilotMode::DefaultsAssault_yaw=3;
	$PilotMode::DefaultsAssault_pitch=3;
	$PilotMode::DefaultsAssault_deadzone=false;
	$PilotMode::DefaultsMPB_yaw=4;
	$PilotMode::DefaultsMPB_pitch=4;
	$PilotMode::DefaultsMPB_deadzone=false;
	$PilotMode::DefaultsShrike_yaw=2;
	$PilotMode::DefaultsShrike_pitch=2;
	$PilotMode::DefaultsShrike_deadzone=false;
	$PilotMode::DefaultsBomber_yaw=4;
	$PilotMode::DefaultsBomber_pitch=4;
	$PilotMode::DefaultsBomber_deadzone=false;
	$PilotMode::DefaultsHAPC_yaw=4;
	$PilotMode::DefaultsHAPC_pitch=4;
	$PilotMode::DefaultsHAPC_deadzone=false;
	// TAC types
	$PilotMode::DefaultsFLPC_yaw=2.5;
	$PilotMode::DefaultsFLPC_pitch=2.5;
	$PilotMode::DefaultsFLPC_deadzone=false;
	$PilotMode::DefaultsTACBomber_yaw=3.5;
	$PilotMode::DefaultsTACBomber_pitch=3.5;
	$PilotMode::DefaultsTACBomber_deadzone=false;
	$PilotMode::DefaultsTACHAPC_yaw=2.5;
	$PilotMode::DefaultsTACHAPC_pitch=2.5;
	$PilotMode::DefaultsTACHAPC_deadzone=false;
	$PilotMode::DefaultsHawkEye_yaw=2;
	$PilotMode::DefaultsHawkEye_pitch=2;
	$PilotMode::DefaultsHawkEye_deadzone=false;

	// if we're missing values for any vehicle, load them, otherwise leave them
	%bind = moveMap.getBinding(pitch); %devicePitch = getField(%bind, 0); %actionPitch = getField(%bind, 1);
	%bind = moveMap.getBinding(yaw); %deviceYaw = getField(%bind, 0); %actionYaw = getField(%bind, 1);
	for (%i = 1; %i <= $PilotMode::numtypes; %i++)
	{
		%type=$PilotMode::VehicleType[%i];
		if ($PilotModePref::Factor[%type, yaw] $= "")
		{
			$PilotModePref::Factor[%type,yaw]=$PilotMode::Defaults[%type,yaw];
    			$PilotModePref::Factor[%type,pitch] = $PilotMode::Defaults[%type,pitch];
			$PilotModePref::Deadzone[%type]=$PilotMode::Defaults[%type,deadzone];
		}
		if ($PilotModePref::Sens[%type, yaw] $= "")
		{
			$PilotModePref::Sens[%type,yaw] = moveMap.getScale(%deviceYaw, %actionYaw)/2;
    			$PilotModePref::Sens[%type,pitch] = moveMap.getScale(%devicePitch, %actionPitch)/2;
		}
	}

	deleteVariables("$PilotMode::Defaults*");
}

function PilotModeDefaults()
{
    // Clear any old variables
    $PilotModePref::convertedsave=true;
    deleteVariables("$PilotModePref::*");
    PilotModeLoadMissing();
}


function clientCmdSetPilotVehicleKeys()
{
    $PilotMode::isPassenger = false;

    parent::clientCmdSetPilotVehicleKeys();
}

function clientCmdSetPassengerVehicleKeys()
{
    $PilotMode::isPassenger = true;

    parent::clientCmdSetPassengerVehicleKeys();
}

};
activatePackage(PilotMode);
// END package PilotMode

PilotModeSetup();
